/**
 * SQL-DK
 * Copyright © 2013 František Kučera (frantovo.cz)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package info.globalcode.sql.dk;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;

/**
 *
 * @author Ing. František Kučera (frantovo.cz)
 */
public class InvalidOptionsException extends Exception {

	private final Collection<OptionProblem> problems = new ArrayList<>();

	public Collection<OptionProblem> getProblems() {
		return Collections.unmodifiableCollection(problems);
	}

	public void addProblem(OptionProblem p) {
		problems.add(p);
	}

	public boolean hasProblems() {
		return !problems.isEmpty();
	}

	public static class OptionProblem {

		private String description;
		private Throwable exception;

		public OptionProblem(String description) {
			this.description = description;
		}

		public OptionProblem(String description, Throwable exception) {
			this.description = description;
			this.exception = exception;
		}

		public String getDescription() {
			return description;
		}

		public Throwable getException() {
			return exception;
		}
	}
}
