/**
 * SQL-DK
 * Copyright © 2013 František Kučera (frantovo.cz)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package info.globalcode.sql.dk;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.util.List;

/**
 * Represents SQL string and its parameters (if there are any).
 *
 * @author Ing. František Kučera (frantovo.cz)
 */
public abstract class SQLCommand {

	private String query;

	public SQLCommand(String query) {
		this.query = query;
	}

	public PreparedStatement prepareStatement(Connection c) throws SQLException {
		return c.prepareStatement(query);
	}

	public abstract void parametrize(PreparedStatement ps) throws SQLException;

	public abstract List<? extends Parameter> getParameters();

	public String getQuery() {
		return query;
	}
}
