/**
 * SQL-DK
 * Copyright © 2013 František Kučera (frantovo.cz)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package info.globalcode.sql.dk;

import static info.globalcode.sql.dk.Functions.notNull;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.util.List;

/**
 * Has ordinal/numbered parameters.
 *
 * @author Ing. František Kučera (frantovo.cz)
 */
public class SQLCommandNumbered extends SQLCommand {

	private List<? extends Parameter> parameters;

	public SQLCommandNumbered(String query, List<? extends Parameter> parameters) {
		super(query);
		this.parameters = parameters;
	}

	@Override
	public void parametrize(PreparedStatement ps) throws SQLException {
		int i = 1;
		for (Parameter p : notNull(parameters)) {
			ps.setObject(i++, p.getValue(), p.getType().getCode());
		}
	}

	@Override
	public List<? extends Parameter> getParameters() {
		return parameters;
	}
}
