/**
 * SQL-DK
 * Copyright © 2013 František Kučera (frantovo.cz)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package info.globalcode.sql.dk.configuration;

import static info.globalcode.sql.dk.Xmlns.CONFIGURATION;
import info.globalcode.sql.dk.DatabaseConnection;
import java.sql.SQLException;
import javax.xml.bind.annotation.XmlElement;

/**
 * Configured (but not yet connected) database connection.
 *
 * @author Ing. František Kučera (frantovo.cz)
 */
public class DatabaseDefinition implements NameIdentified {

	private String name;
	private String url;
	private String userName;
	private String password;
	private Properties properties = new Properties();

	@XmlElement(name = "name", namespace = CONFIGURATION)
	@Override
	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	@XmlElement(name = "url", namespace = CONFIGURATION)
	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	@XmlElement(name = "userName", namespace = CONFIGURATION)
	public String getUserName() {
		return userName;
	}

	public void setUserName(String userName) {
		this.userName = userName;
	}

	@XmlElement(name = "password", namespace = CONFIGURATION)
	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	@XmlElement(name = "property", namespace = CONFIGURATION)
	public Properties getProperties() {
		return properties;
	}

	public void setProperties(Properties properties) {
		this.properties = properties;
	}

	/**
	 * @param properties ad-hoc properties from CLI options (for the JDBC driver)
	 */
	public DatabaseConnection connect(Properties properties) throws SQLException {
		return new DatabaseConnection(this, properties);
	}
}
