/**
 * SQL-DK
 * Copyright © 2014 František Kučera (frantovo.cz)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package info.globalcode.sql.dk.formatting;

import info.globalcode.sql.dk.SQLType;
import java.sql.Array;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Map;

/**
 * Fake SQL array, for formatting purposes only
 *
 * @author Ing. František Kučera (frantovo.cz)
 */
public class FakeSqlArray implements Array {

	private static final UnsupportedOperationException exception = new UnsupportedOperationException("This is just a fake SQL array.");
	private final Object[] data;
	private final SQLType baseType;

	public FakeSqlArray(Object[] data, SQLType baseType) {
		this.data = data;
		this.baseType = baseType;
	}

	@Override
	public String toString() {
		StringBuilder string = new StringBuilder();
		for (Object o : data) {
			string.append(o);
			string.append("\n");
		}
		return string.toString();
	}

	@Override
	public String getBaseTypeName() throws SQLException {
		return baseType.name();
	}

	@Override
	public int getBaseType() throws SQLException {
		return baseType.getCode();
	}

	@Override
	public Object getArray() throws SQLException {
		return data;
	}

	@Override
	public Object getArray(Map<String, Class<?>> map) throws SQLException {
		throw exception;
	}

	@Override
	public Object getArray(long index, int count) throws SQLException {
		throw exception;
	}

	@Override
	public Object getArray(long index, int count, Map<String, Class<?>> map) throws SQLException {
		throw exception;
	}

	@Override
	public ResultSet getResultSet() throws SQLException {
		throw exception;
	}

	@Override
	public ResultSet getResultSet(Map<String, Class<?>> map) throws SQLException {
		throw exception;
	}

	@Override
	public ResultSet getResultSet(long index, int count) throws SQLException {
		throw exception;
	}

	@Override
	public ResultSet getResultSet(long index, int count, Map<String, Class<?>> map) throws SQLException {
		throw exception;
	}

	@Override
	public void free() throws SQLException {
		throw exception;
	}
}
