/**
 * SQL-DK
 * Copyright © 2013 František Kučera (frantovo.cz)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package info.globalcode.sql.dk.formatting;

import java.io.PrintWriter;

/**
 * Prints just the value without any formatting. If the result set contains multiple records or
 * columns, the values are simply concatenate without any separators. If updates result is returned,
 * the updated records count is printed.
 *
 * @author Ing. František Kučera (frantovo.cz)
 */
public class SingleValueFormatter extends AbstractFormatter {

	public static final String NAME = "single"; // bash-completion:formatter
	private PrintWriter out;

	public SingleValueFormatter(FormatterContext formatterContext) {
		super(formatterContext);
		this.out = new PrintWriter(formatterContext.getOutputStream());
	}

	@Override
	public void writeColumnValue(Object value) {
		super.writeColumnValue(value);
		out.print(String.valueOf(value));
		out.flush();
	}

	@Override
	public void writeUpdatesResult(int updatedRowsCount) {
		super.writeUpdatesResult(updatedRowsCount);
		out.print(updatedRowsCount);
		out.flush();
	}
}
